==> Bundle-Elkhound-0.01.tar.gz: Bundle-Elkhound-0.01/lib/Bundle/Elkhound.pm <==
package Bundle::Elkhound;

use 5.005;
use strict;

our $VERSION = '0.01';

1;
__END__

=head1 NAME

Bundle::Moose - Perl extension to install and/or upgrade
                all dependencies for Moose

=head1 SYNOPSIS

cpan> install Bundle::Elkhound
  
=head1 DESCRIPTION

This script provides an easy way to determine if you have
all the prerequisites and dependencies for Moose

=head1 CONTENTS

Bundle::Compress::Zlib

Bundle::dualLived

Acme::Unknown::Missing::Module::Name

Test::Requires

Devel::Hide

B::Hooks::EndOfScope

namespace::clean

Test::Pod

Test::Pod::Coverage

namespace::autoclean

Declare::Constraints::Simple

Data::OptList

Devel::GlobalDestruction

Sub::Name

Eval::Closure

Params::Classify

Params::Check

Text::Table

Test::Exception

Test::Deep

SQL::Statement

MLDBM

DBM::Deep

Net::Daemon

RPC::PlClient

DBI

DBD::CSV

DBD::SQLite

DBIx::Connector

Algorithm::Combinatorics

Test::JSON

XML::Namespace

Set::Scalar

XML::CommonNS

Geo::Distance

Crypt::GPG

RDF::Trine

File::Slurp

HTTP::Negotiate

HTTP::Daemon

Net::HTTP

HTTP::Cookies

WWW::RobotRules

LWP::Simple

Perl::Version
URI

Math::Round

Class::Singleton

Sub::Exporter
Dist::CheckConflicts

Sub::Install

Log::Log4perl

Text::CSV

XML::NamespaceFactory

XML::NamespaceSupport

XML::SAX::Base

XML::SAX
Text::Aligner

File::Listing
LWP::UserAgent

Data::UUID

JSON

JSON::Syck

JSON::XS

JSON::Any

Test::Tester

common::sense

Algorithm::Diff

Text::Diff

Test::Differences

Error

RDF::Query

Module::Install::DOAPChangeSets

Module::Install

Text::Abbrev

Lingua::EN::Sentence

Template

YAML

HTML::Tagset

HTML::Parser

Task::Weaken

Class::Inspector

Hook::LexWrap

Test::SubCalls

Digest::base

Clone
Test::NoWarnings

Test::Object

PPI

Locale::Maketext::Lexicon

Module::Runtime

Test::Fatal

Algorithm::C3

Class::C3

MRO::Compat

Package::DeprecationManager

Params::Util

Try::Tiny

DateTime::Locale

DateTime::TimeZone

DateTime

Class::Factory::Util
DateTime::Format::Strptime

DateTime::Format::Builder

DateTime::Format::MySQL

DateTime::Calendar::Mayan

File::Find::Rule

HTTP::Headers

IO::String

Data::Section::Simple

Locale::US

Module::Info

Path::Class

Module::Refresh

PadWalker

Params::Coerce

Regexp::Common

Sub::Identify

asa

Test::use::ok

IO::Handle::Util

Log::Dispatch

YAML::Syck

Compress::Bzip2

Term::ReadKey

YAML::LibYAML

Archive::Zip

IO::Pty

IPC::Run

Module::Signature

autodie

File::Which

File::HomeDir

File::ShareDir

ORLite

ORLite::Mirror

Net::FTP

HTTP::Date

IO::Uncompress::Inflate

HTTP::Status

Encode::Locale

LWP::MediaTypes

LWP::Online

IPC::Run3

Probe::Perl

Test::Script

File::Remove

Number::Format

Statistics::Basic

ORLite::Statistics
File::chdir

Scope::Guard

B::Keywords

Readonly

Readonly::XS

PPIx::Utilities::Statement

Perl::Tidy

String::Format

PPIx::Regexp

Perl::Critic

Test::Perl::Critic

Carp

Expect

CPANDB

File::chmod

Algorithm::Dependency

File::Copy::Recursive

prefork

File::Flat

Config::Tiny

Test::ClassAPI

Pod::Tests

Text::Glob

Test::Inline

Test::LeakTrace

Test::Output

Test::Spelling

Class::Load

Class::Load::XS

Moose

MooseX::Role::WithOverloading

Data::Visitor

Package::Stash::XS

Package::Stash

Devel::PartialDump

Task::Moose

=head1 CAVEATS

Bundle::Elkhound is designed for the most current version of Moose,
the version on cpan.

=head1 AUTHOR

Version 0.01 Kevin W. Henwood <Khen1950fx@aol.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2010, 2011 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.5.0 or,
at your option, any later version of Perl 5 you may have available.


=cut

==> Bundle-Elkhound-0.02.tar.gz: Bundle-Elkhound-0.02/lib/Bundle/Elkhound.pm <==
package Bundle::Elkhound;

use 5.005;
use strict;

our $VERSION = '0.02';

1;
__END__

=head1 NAME

Bundle::Moose - Perl extension to install and/or upgrade
                all dependencies for Moose

=head1 SYNOPSIS

cpan> install Bundle::Elkhound
  
=head1 DESCRIPTION

This script provides an easy way to determine if you have
all the prerequisites and dependencies for Moose

=head1 CONTENTS

Bundle::Compress::Zlib

Bundle::dualLived

Test::Requires

Devel::Hide

B::Hooks::EndOfScope

Data::OptList

Sub::Exporter

Dist::CheckConflicts

List::MoreUtils

Sub::Install

Params::Util

Carp

Try::Tiny

Test::Fatal

Package::Stash

Package::DeprecationManager

namespace::clean

Test::Pod

Test::Pod::Coverage

namespace::autoclean

aliased

Class::Inspector

Sub::Uplevel

Test::Exception

Carp::Clan

Declare::Constraints::Simple

Devel::GlobalDestruction

Sub::Name

Eval::Closure

Params::Classify

Text::Aligner

Text::Table

Test::NoWarnings

Test::Tester

Test::Deep

Clone

Data::Dumper

SQL::Statement

MLDBM

Digest::MD5

Tree::DAG_Node

DBM::Deep

Net::Daemon

RPC::PlClient

DBI

DBD::File

Text::CSV

Text::CSV_XS

DBD::CSV

DBD::SQLite

Test::MockModule

DBIx::Connector

FindBin::Real

Algorithm::Combinatorics

JSON

JSON::XS

JSON::Any

JSON::Syck

common::sense

Algorithm::Diff

Text::Diff

Test::JSON

XML::Namespace

Set::Scalar

XML::NamespaceFactory

XML::CommonNS

Math::Complex

Geo::Distance

Date::Parse

Crypt::GPG

RDF::Trine

File::Slurp

HTTP::Negotiate

HTTP::Daemon

Net::HTTP

HTTP::Cookies

WWW::RobotRules

LWP::Simple

Perl::Version

URI

Math::Round

Class::Singleton

Log::Log4perl

XML::NamespaceSupport

XML::SAX::Base

XML::SAX

File::Listing

LWP::UserAgent

Data::UUID

Test::Differences

Error

RDF::Query

Module::Install::DOAPChangeSets

Lingua::EN::Sentence

Template

YAML

HTML::Tagset

HTML::Parser

Task::Weaken

Hook::LexWrap

Test::SubCalls

Digest::base

Test::Object

PPI

Locale::Maketext::Lexicon

Module::Runtime

Algorithm::C3

Class::C3

MRO::Compat

DateTime::Locale

DateTime::TimeZone

DateTime

Class::Factory::Util

DateTime::Format::Strptime

DateTime::Format::Builder

DateTime::Format::MySQL

DateTime::Calendar::Mayan

File::Find::Rule

HTTP::Headers

IO::String

Data::Section::Simple

Locale::US

Module::Info

Path::Class

Module::Refresh

PadWalker

Params::Coerce

Regexp::Common

Sub::Identify

asa

Test::use::ok

IO::Handle::Util

Log::Dispatch

YAML::Syck

Term::ReadKey

YAML::LibYAML

Archive::Zip

IO::Pty

IPC::Run

Module::Signature

autodie

File::Which

File::HomeDir

File::ShareDir

ORLite

ORLite::Mirror

HTTP::Date

IO::Uncompress::Inflate

HTTP::Status

Encode::Locale

LWP::MediaTypes

LWP::Online

IPC::Run3

Probe::Perl

Test::Script

File::Remove

Number::Format

Statistics::Basic

ORLite::Statistics

File::chdir

Scope::Guard

B::Keywords

Readonly

Readonly::XS

PPIx::Utilities::Statement

Perl::Tidy

String::Format

PPIx::Regexp

Perl::Critic

Test::Perl::Critic

Expect

CPANDB

File::chmod

Algorithm::Dependency

File::Copy::Recursive

prefork

File::Flat

Config::Tiny

Test::ClassAPI

Pod::Tests

Text::Glob

Test::Inline

Test::LeakTrace

Test::Output

Test::Spelling

Class::Load

Class::Load::XS

Moose

MooseX::Role::WithOverloading

Data::Visitor

Package::Stash::XS

Devel::PartialDump

Task::Moose

=head1 CAVEATS

Bundle::Elkhound is designed for the most current version of Moose,
the version on cpan.

=head1 AUTHOR

Version 0.02 Kevin W. Henwood <Khen1950fx@aol.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2012 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.5.0 or,
at your option, any later version of Perl 5 you may have available.


=cut
